@@ -1,8 +1,9 @@
 use std::path::Path;
 
 use off_rs::{
-    geometry::ColorFormat,
-    mesh::{Mesh, ParserOptions},
+    geometry::{color_format::ColorFormat, mesh::Mesh},
+    parser::options::Options,
+    FromPath,
 };
 
 const PATH: &str = concat!(env!("CARGO_MANIFEST_DIR"), "/examples/cube.off");
@@ -10,7 +11,7 @@ const PATH: &str = concat!(env!("CARGO_MANIFEST_DIR"), "/examples/cube.off");
 fn main() {
     let mesh = Mesh::from_path(
         Path::new(PATH),
-        ParserOptions {
+        Options {
             color_format: ColorFormat::RGBAFloat,
             ..Default::default()
         },
